==> hazelcast-all-4.1-sources.jar: com/hazelcast/org/apache/calcite/interpreter/CollectNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in com.hazelcast.com.liance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.com.hazelcast.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.hazelcast.org.apache.calcite.interpreter;

import com.hazelcast.org.apache.calcite.rel.core.Collect;

import com.hazelcast.com.google.com.hazelcast.com.on.collect.ImmutableList;

import java.util.ArrayList;
import java.util.List;

/**
 * Interpreter node that implements a
 * {@link com.hazelcast.org.apache.calcite.rel.core.Collect}.
 */
public class CollectNode extends AbstractSingleNode<Collect> {

  public CollectNode(Compiler com.hazelcast.com.iler, Collect rel) {
    super(com.hazelcast.com.iler, rel);
  }

  @Override public void run() throws InterruptedException {
    Row row;
    List<Object[]> values = new ArrayList<>();
    while ((row = source.receive()) != null) {
      values.add(row.getValues());
    }
    row = Row.of(ImmutableList.copyOf(values));
    sink.send(row);
  }
}

==> hazelcast-all-4.2.4-sources.jar: com/hazelcast/org/apache/calcite/interpreter/CollectNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.hazelcast.org.apache.calcite.interpreter;

import com.hazelcast.org.apache.calcite.rel.core.Collect;

import com.hazelcast.com.google.common.collect.ImmutableList;

import java.util.ArrayList;
import java.util.List;

/**
 * Interpreter node that implements a
 * {@link com.hazelcast.org.apache.calcite.rel.core.Collect}.
 */
public class CollectNode extends AbstractSingleNode<Collect> {

  public CollectNode(Compiler compiler, Collect rel) {
    super(compiler, rel);
  }

  @Override public void run() throws InterruptedException {
    Row row;
    List<Object[]> values = new ArrayList<>();
    while ((row = source.receive()) != null) {
      values.add(row.getValues());
    }
    row = Row.of(ImmutableList.copyOf(values));
    sink.send(row);
  }
}
